@@ -39,16 +39,6 @@
 
 typedef struct a_pid a_pid;
 
-/*!
- @brief enumeration for PID controller
-*/
-enum
-{
-    A_PID_RUN, //!< run and output setpoint
-    A_PID_POS, //!< positional PID controller
-    A_PID_INC //!< incremental PID controller
-};
-
 #if defined(__cplusplus)
 extern "C" {
 #endif /* __cplusplus */
@@ -57,13 +47,7 @@ extern "C" {
  @brief initialize for PID controller
  @param[in,out] ctx points to an instance of PID controller
 */
-A_EXTERN void a_pid_init(a_pid *ctx);
-
-/*!
- @brief zeroing for PID controller
- @param[in,out] ctx points to an instance of PID controller
-*/
-A_EXTERN void a_pid_zero(a_pid *ctx);
+#define a_pid_init(ctx) a_pid_zero(ctx)
 
 /*!
  @brief set proportional integral derivative constant for PID controller
@@ -101,6 +85,12 @@ A_EXTERN a_float a_pid_pos(a_pid *ctx, a_float set, a_float fdb);
 */
 A_EXTERN a_float a_pid_inc(a_pid *ctx, a_float set, a_float fdb);
 
+/*!
+ @brief zeroing for PID controller
+ @param[in,out] ctx points to an instance of PID controller
+*/
+A_EXTERN void a_pid_zero(a_pid *ctx);
+
 #if defined(__cplusplus)
 } /* extern "C" */
 namespace a
@@ -122,11 +112,12 @@ struct a_pid
     a_float sum; //!< controller integral output
     a_float outmax; //!< maximum final output
     a_float outmin; //!< minimum final output
-    a_float out; //!< controller output
-    a_float fdb; //!< cache feedback
+    a_float out; //!< controller final output
     a_float var; //!< cache variable
+    a_float fdb; //!< cache feedback
     a_float err; //!< cache error
 #if defined(__cplusplus)
+    A_INLINE void init() { a_pid_init(this); }
     A_INLINE void kpid(a_float _kp, a_float _ki, a_float _kd)
     {
         a_pid_kpid(this, _kp, _ki, _kd);
@@ -143,7 +134,6 @@ struct a_pid
     {
         return a_pid_inc(this, set, _fdb);
     }
-    A_INLINE void init() { a_pid_init(this); }
     A_INLINE void zero() { a_pid_zero(this); }
 #endif /* __cplusplus */
 };
