@@ -1,16 +1,5 @@
 #include "a/pid.h"
 
-void a_pid_init(a_pid *ctx)
-{
-    ctx->sum = 0;
-    ctx->out = 0;
-    ctx->fdb = 0;
-    ctx->var = 0;
-    ctx->err = 0;
-}
-
-void a_pid_zero(a_pid *ctx) { a_pid_init(ctx); }
-
 void a_pid_kpid(a_pid *ctx, a_float kp, a_float ki, a_float kd)
 {
     ctx->kp = kp;
@@ -27,8 +16,8 @@ a_float a_pid_run_(a_pid *ctx, a_float set, a_float fdb, a_float err)
 {
     a_float const var = ctx->fdb - fdb;
     ctx->out = A_SAT(set, ctx->outmin, ctx->outmax);
-    ctx->fdb = fdb;
     ctx->var = var;
+    ctx->fdb = fdb;
     ctx->err = err;
     return ctx->out;
 }
@@ -53,8 +42,8 @@ a_float a_pid_pos_(a_pid *ctx, a_float fdb, a_float err)
     // Avoid derivative kick, fdb[k-1]-fdb[k]. out = K_p[err(k)]+sum+K_d[fdb(k-1)-fdb(k)].
     ctx->out = ctx->kp * err + ctx->sum + ctx->kd * var;
     ctx->out = A_SAT(ctx->out, ctx->outmin, ctx->outmax);
-    ctx->fdb = fdb;
     ctx->var = var;
+    ctx->fdb = fdb;
     ctx->err = err;
     return ctx->out;
 }
@@ -69,8 +58,17 @@ a_float a_pid_inc_(a_pid *ctx, a_float fdb, a_float err)
     a_float const var = ctx->fdb - fdb;
     ctx->out += ctx->kp * (err - ctx->err) + ctx->ki * err + ctx->kd * (var - ctx->var);
     ctx->out = A_SAT(ctx->out, ctx->outmin, ctx->outmax);
-    ctx->fdb = fdb;
     ctx->var = var;
+    ctx->fdb = fdb;
     ctx->err = err;
     return ctx->out;
 }
+
+void a_pid_zero(a_pid *ctx)
+{
+    ctx->sum = 0;
+    ctx->out = 0;
+    ctx->var = 0;
+    ctx->fdb = 0;
+    ctx->err = 0;
+}
